"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Layer = exports.LayerContext = exports.PracticalProvider = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _resizeObserver = require("@juggle/resize-observer");

var _reactHooksShareable = require("react-hooks-shareable");

var _theme = require("./theme");

var _ToastsProvider = require("./Toast/ToastsProvider");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var PracticalRoot = _styledComponents.default.div.withConfig({
  displayName: "Practical__PracticalRoot",
  componentId: "sc-1lggjit-0"
})(["color:", ";"], (_ref) => {
  var {
    theme
  } = _ref;
  return theme.color.text01();
});

var PracticalContext = /*#__PURE__*/(0, _react.createContext)({
  rootEl: undefined
});
var DEFAULT_TOASTS_OPTIONS = {
  placement: {
    justify: 'right',
    top: '0'
  },
  alwaysOnTop: true,
  defaultDurations: {
    success: 4000
  }
};

var PracticalProvider = (_ref2) => {
  var {
    theme = _theme.defaultTheme,
    toastsOptions = DEFAULT_TOASTS_OPTIONS,
    children
  } = _ref2;
  var [rootEl, rootRef] = (0, _react.useState)(null);
  return /*#__PURE__*/_react.default.createElement(_styledComponents.ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/_react.default.createElement(PracticalContext.Provider, {
    value: {
      rootEl
    }
  }, /*#__PURE__*/_react.default.createElement(_ToastsProvider.ToastsProvider, toastsOptions.defaultDurations, /*#__PURE__*/_react.default.createElement(PracticalRoot, {
    id: "practical-root",
    ref: rootRef
  }, /*#__PURE__*/_react.default.createElement(Layer, null, children), /*#__PURE__*/_react.default.createElement(Layer, {
    zIndex: toastsOptions.alwaysOnTop ? 1 : 0
  }, /*#__PURE__*/_react.default.createElement(_ToastsProvider.ToastsAnchor, {
    placement: toastsOptions.placement
  }))))));
};
/**
 * Layer
 *
 * A layer creates a new div element that is rendered
 * a sibling to the previous layer and a child of the
 * practical root.
 *
 * Other components can access the layer element and id
 * through the LayerContext.
 *
 * Layers cannot be clicked on, but all children of it
 * can be clicked on. Wowy!
 */


exports.PracticalProvider = PracticalProvider;
var LAYER_ID_PREFIX = 'layer';

var LayerContainer = _styledComponents.default.div.withConfig({
  displayName: "Practical__LayerContainer",
  componentId: "sc-1lggjit-1"
})(["position:absolute;z-index:", ";"], (_ref3) => {
  var {
    zIndex = 0
  } = _ref3;
  return zIndex;
});

var LayerContext = /*#__PURE__*/(0, _react.createContext)({
  el: typeof document !== 'undefined' ? document.body : null,
  id: LAYER_ID_PREFIX
});
exports.LayerContext = LayerContext;

var Layer = (_ref4) => {
  var {
    children,
    zIndex
  } = _ref4;
  var {
    rootEl
  } = (0, _react.useContext)(PracticalContext);
  var [el, ref] = (0, _react.useState)(null);
  var id = (0, _reactHooksShareable.useId)(LAYER_ID_PREFIX);

  if (rootEl === undefined) {
    throw new Error('You need to wrap your application in a PracticalProvider component, otherwise layers do not work.');
  }

  if (rootEl === null) {
    return null;
  }

  return /*#__PURE__*/_reactDom.default.createPortal( /*#__PURE__*/_react.default.createElement(LayerContext.Provider, {
    value: {
      el,
      id
    }
  }, /*#__PURE__*/_react.default.createElement(LayerContainer, {
    id: id,
    ref: ref,
    zIndex: zIndex
  }, children)), rootEl);
}; // Add ResizeObserver polyfill from juggle if not available


exports.Layer = Layer;

if (typeof window !== 'undefined') {
  if (window.ResizeObserver === undefined) {
    /* eslint-disable-next-line @typescript-eslint/ban-ts-comment */
    // @ts-ignore
    window.ResizeObserver = _resizeObserver.ResizeObserver;
  }
}