import React from 'react';
import { ButtonClickHandler } from '../Button';
export interface StepperAction {
    /**
     * The label for the stepper button (previous, next or complete action).
     */
    readonly label: string;
    /**
     * The click handler for the stepper button (previous, next or complete action).
     */
    readonly onClick?: ButtonClickHandler;
}
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
export interface StepContent extends BaseProps {
    readonly label: string;
    readonly content: React.ReactNode;
    readonly hasErrors?: boolean;
    readonly disableNext?: boolean;
}
export declare const StepControls: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
interface StepProps extends Omit<StepContent, 'content'> {
    /**
     * The function that run on action button click in the last stepper step.
     */
    readonly completeAction: StepperAction;
    /**
     * The function that runs on previous button click.
     */
    readonly prevAction: StepperAction;
    /**
     * The function that runs on next button click.
     */
    readonly nextAction: StepperAction;
    /**
     * The function that runs on reset button click.
     */
    readonly resetAction: StepperAction;
    readonly children: React.ReactNode;
    readonly currentStep: number;
    readonly stepId: number;
    readonly setCurrentStep: (step: number) => void;
    readonly completedSteps: ReadonlyArray<number>;
    readonly setCompletedSteps: (steps: ReadonlyArray<number>) => void;
    readonly numberOfSteps: number;
    readonly hasAnyErrors: boolean;
    readonly disableNext?: boolean;
}
export declare const Step: React.FC<StepProps>;
export {};
