"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ColumnResizerRow = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactHooksShareable = require("react-hooks-shareable");

var _designparams = require("../designparams");

var _dimensions = require("./dimensions");

var _context = require("./context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Clip the translation of a divider so that it remains
 * within the total width of the two columns it divides.
 *
 * @param tx Divider translation
 * @param divider Divider
 */
var clipTranslation = (tx, divider, minWidth) => {
  var {
    before,
    after
  } = divider;
  var txMin = minWidth - before;
  var txMax = after - minWidth;
  return Math.min(Math.max(txMin, tx), txMax);
};
/*******************************************************************************
 *
 * Column resizing.
 *
 ******************************************************************************/


var ResizeContainer = _styledComponents.default.div.attrs((_ref) => {
  var {
    left
  } = _ref;
  return {
    style: {
      left: "".concat(left - 8, "px")
    }
  };
}).withConfig({
  displayName: "ColumnResizerRow__ResizeContainer",
  componentId: "sc-1khw7xf-0"
})(["display:relative;position:absolute;width:16px;top:0;height:100%;pointer-events:none;"]);
/**
 * ResizeHandle
 *
 * A special component to keep track of the size of its element
 * and pass it to a function that can alter the size globally.
 */


var ResizeHandle = _styledComponents.default.div.withConfig({
  displayName: "ColumnResizerRow__ResizeHandle",
  componentId: "sc-1khw7xf-1"
})(["position:absolute;width:16px;top:0;left:0;height:", ";cursor:ew-resize;pointer-events:all;"], _designparams.componentSize.large);
/**
 * ResizeMarker
 *
 * A vertical line marking the edge of the new column.
 */


var ResizeMarker = _styledComponents.default.div.withConfig({
  displayName: "ColumnResizerRow__ResizeMarker",
  componentId: "sc-1khw7xf-2"
})(["display:", ";position:absolute;width:1px;top:0;bottom:0;left:8px;background-color:", ";", ":hover + &{display:unset;}"], (_ref2) => {
  var {
    dragging
  } = _ref2;
  return dragging ? 'unset' : 'none';
}, (_ref3) => {
  var {
    theme
  } = _ref3;
  return theme.color.background01();
},
/* sc-selector */
ResizeHandle);
/**
 * ColumnResizer
 *
 * A draggable resize handle that will dispatch a new
 * column width when dragging ends. During dragging,
 * a resize marker is shown to follow the change in width.
 */


var ColumnResizer = (_ref4) => {
  var {
    divider,
    setDragging,
    onDragEnd
  } = _ref4;
  var {
    minColumnWidth
  } = (0, _react.useContext)(_context.TableContext);
  var [[tx], onDragStart, dragging] = (0, _reactHooksShareable.useDraggable)(onDragEnd);
  var txClipped = clipTranslation(tx, divider, minColumnWidth);
  (0, _react.useEffect)(() => {
    setDragging(dragging);

    if (dragging) {
      document.body.style.cursor = 'ew-resize';
      return () => {
        document.body.style.cursor = '';
      };
    }
  }, [dragging, setDragging]);
  return /*#__PURE__*/_react.default.createElement(ResizeContainer, {
    left: divider.offset + txClipped
  }, /*#__PURE__*/_react.default.createElement(ResizeHandle, {
    onPointerDown: onDragStart
  }), /*#__PURE__*/_react.default.createElement(ResizeMarker, {
    dragging: dragging
  }));
};
/**
 * ColumnResizerRow
 *
 * A collection of resize handlers.
 */


var ColumnResizerRow = (_ref5) => {
  var {
    setDragging
  } = _ref5;
  var {
    minColumnWidth,
    columnWidths,
    dispatchWidthsAction,
    onSelect,
    onWidthsChange
  } = (0, _react.useContext)(_context.TableContext);
  /**
   * The global offset of all resize handles.
   * This is used e.g. when there is a column
   * of checkboxes that needs to be taken into account.
   */

  var globalOffset = _dimensions.TABLE_DIMENSIONS.PADDING_LEFT + (onSelect !== undefined ? _dimensions.TABLE_DIMENSIONS.SELECT_WIDTH : 0);
  var dividers = (0, _react.useMemo)(() => {
    var result = [];
    var offset = globalOffset;

    for (var i = 0; i < columnWidths.length - 1; i += 1) {
      offset = offset + columnWidths[i];
      result.push({
        offset,
        before: columnWidths[i],
        after: columnWidths[i + 1]
      });
    }

    return result;
  }, [columnWidths, globalOffset]);
  var moveDivider = (0, _react.useCallback)((x, dividerIndex) => {
    var divider = dividers[dividerIndex];
    var xClipped = clipTranslation(x, divider, minColumnWidth);
    dispatchWidthsAction({
      type: _context.WidthActionType.UPDATE_WIDTHS,
      widths: {
        [dividerIndex]: divider.before + xClipped,
        [dividerIndex + 1]: divider.after - xClipped
      },
      onWidthsChange
    });
  }, [dividers, dispatchWidthsAction, minColumnWidth, onWidthsChange]);
  var dragEndHandlers = (0, _react.useMemo)(() => {
    return [...Array(dividers.length).keys()].map(i => (_ref6) => {
      var [tx] = _ref6;
      return moveDivider(tx, i);
    });
  }, [dividers.length, moveDivider]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, dividers.map((divider, i) => {
    return /*#__PURE__*/_react.default.createElement(ColumnResizer, {
      setDragging: setDragging,
      key: "".concat(i, ":").concat(divider.offset),
      divider: divider,
      onDragEnd: dragEndHandlers[i]
    });
  }));
};

exports.ColumnResizerRow = ColumnResizerRow;