"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TableHeader = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _designparams = require("../designparams");

var _Checkbox = require("../Checkbox");

var _Table = require("./Table");

var _context = require("./context");

var _TableCells = require("./TableCells");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/*
 * TableHeader
 *
 * Defines the group of special cells that make up the header
 * of the table. They allow to resize the columns.
 * You should use this to wrap the elements you pass to the
 * header property of the Table component.
 */
var TableHeaderGrid = _styledComponents.default.div.withConfig({
  displayName: "TableHeader__TableHeaderGrid",
  componentId: "sc-1wnct30-0"
})(["display:grid;grid-template-rows:", ";"], _designparams.componentSize.large);

var TableHeader = (_ref) => {
  var {
    children,
    selected = false,
    partial = false,
    overlay,
    menu
  } = _ref,
      props = _objectWithoutProperties(_ref, ["children", "selected", "partial", "overlay", "menu"]);

  var {
    onSelect,
    hasMenu,
    columnWidths,
    dispatchWidthsAction
  } = (0, _react.useContext)(_context.TableContext);
  var onChange = (0, _react.useCallback)(e => {
    if (onSelect !== undefined) {
      onSelect(e.target.checked);
    }
  }, [onSelect]);

  var numberOfColumns = _react.default.Children.count(children); // Set the column widths.
  // This will happen on first render (number of columns changes from 0).


  (0, _react.useEffect)(() => {
    if (columnWidths.length === 0) {
      dispatchWidthsAction({
        type: _context.WidthActionType.RESET_WIDTHS,
        numberOfColumns
      });
    }
  }, [dispatchWidthsAction, columnWidths.length, numberOfColumns]);
  var gridTemplateColumnsStyle = (0, _Table.useGridTemplateColumns)();
  return /*#__PURE__*/_react.default.createElement(TableHeaderGrid, _extends({
    style: gridTemplateColumnsStyle
  }, props), onSelect !== undefined ? /*#__PURE__*/_react.default.createElement(_TableCells.TableHeaderCellCheckbox, null, /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, {
    checked: selected,
    partial: partial,
    onChange: onChange
  })) : null, overlay !== undefined ? /*#__PURE__*/_react.default.createElement(_TableCells.OverlayContainer, null, overlay) : _react.default.Children.map(children, (cell, i) => {
    return /*#__PURE__*/_react.default.createElement(_TableCells.TableHeaderCellContent, {
      key: i
    }, cell);
  }), overlay === undefined && hasMenu ? /*#__PURE__*/_react.default.createElement(_TableCells.TableHeaderCellMenu, null, menu !== undefined ? menu : null) : null);
};

exports.TableHeader = TableHeader;