import React from 'react';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
export interface TableRowProps extends BaseProps {
    readonly children: React.ReactNodeArray;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * ID for the row, used in the onSelect handler
     */
    readonly id: string;
    /**
     * Indicates if the row is selected or not.
     */
    readonly selected?: boolean;
    /**
     * Optional menu content to put on the right.
     * It will be aligned to the right and overflow onto the row.
     */
    readonly menu?: React.ReactNode;
    /**
     * Optional flag to disable entire row.
     */
    readonly disabled?: boolean;
    /**
     * If the row is clickable.
     * Note: If row is clickable, row can not be selectable.
     */
    readonly clickable?: boolean;
    /**
     * Function callback on row clicked
     */
    readonly onClicked?: React.MouseEventHandler<HTMLDivElement>;
}
export declare const TableRow: React.FC<TableRowProps>;
export {};
