"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useToasts = exports.useToastCallbacks = void 0;

var _react = require("react");

var _toastActions = require("./toastActions");

var _toastCreators = require("./toastCreators");

var _context = require("./context");

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var useToastCallbacks = function useToastCallbacks(dispatchRef) {
  var {
    success,
    error,
    warning,
    info
  } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var showToast = (0, _react.useCallback)((toast, id) => {
    var toastAction = (0, _toastActions.createToast)(toast, id);
    dispatchRef.current(toastAction);
    return toastAction.id;
  }, [dispatchRef]);
  var hideToast = (0, _react.useCallback)(id => {
    var toastAction = (0, _toastActions.removeToast)(id);
    dispatchRef.current(toastAction);
  }, [dispatchRef]);
  var clearToasts = (0, _react.useCallback)(() => {
    dispatchRef.current(_toastActions.removeAllToasts);
  }, [dispatchRef]);
  var showSuccessToast = (0, _react.useCallback)((toast, id) => showToast(_objectSpread({
    duration: success
  }, (0, _toastCreators.createSuccessToast)(toast)), id), [showToast, success]);
  var showErrorToast = (0, _react.useCallback)((toast, id) => showToast(_objectSpread({
    duration: error
  }, (0, _toastCreators.createErrorToast)(toast)), id), [showToast, error]);
  var showInfoToast = (0, _react.useCallback)((toast, id) => showToast(_objectSpread({
    duration: info
  }, (0, _toastCreators.createInfoToast)(toast)), id), [showToast, info]);
  var showWarningToast = (0, _react.useCallback)((toast, id) => showToast(_objectSpread({
    duration: warning
  }, (0, _toastCreators.createWarningToast)(toast)), id), [showToast, warning]);
  var showLoadingToast = (0, _react.useCallback)((toast, id) => {
    return showToast((0, _toastCreators.createLoadingToast)(toast), id);
  }, [showToast]);
  var showProgressToast = (0, _react.useCallback)((toast, id) => {
    return showToast((0, _toastCreators.createProgressToast)(toast), id);
  }, [showToast]);
  var showActionToast = (0, _react.useCallback)((toast, id) => showToast((0, _toastCreators.createActionToast)(toast), id), [showToast]);
  return {
    showToast,
    hideToast,
    clearToasts,
    showSuccessToast,
    showErrorToast,
    showInfoToast,
    showWarningToast,
    showLoadingToast,
    showProgressToast,
    showActionToast
  };
};

exports.useToastCallbacks = useToastCallbacks;

var useToasts = () => {
  var _useContext = (0, _react.useContext)(_context.ToastsContext),
      {
    __dispatchRef
  } = _useContext,
      callbacks = _objectWithoutProperties(_useContext, ["__dispatchRef"]);

  return callbacks;
};

exports.useToasts = useToasts;